#
# spec file for package python-jupyter_notebook-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Building docs needs root access
%bcond_with pdf
%bcond_with html

%if 0%{?suse_version} && 0%{?suse_version} > 1320
%bcond_without tests
%else
%bcond_with tests
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_notebook-doc
Version:        5.4.1
Release:        lp150.1.1
Summary:        Documentation for python-jupyter_notebook
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/notebook
Source:         https://files.pythonhosted.org/packages/source/n/notebook/notebook-%{version}.tar.gz
BuildRequires:  %{python_module jupyter_notebook = %{version}}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
# Test Requirements
BuildRequires:  %{python_module nose_warnings_filters}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module requests}
# Python 2.7 test requirements
BuildRequires:  python-mock
%endif
# Documentation requirements
%if %{with pdf} || %{with html}
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  python3-Sphinx
BuildRequires:  python3-jupyter_nbsphinx
BuildRequires:  python3-matplotlib
BuildRequires:  python3-numpydoc
BuildRequires:  python3-requests
%endif
%if %{with pdf}
BuildRequires:  pandoc
BuildRequires:  python3-Sphinx-latex
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       %{python_module jupyter_notebook-doc = %{version}}

%description
Documentation and help files for python-jupyter_notebook.

%prep
%setup -q -n notebook-%{version}

%build
# Build the documentation
pushd docs
%if %{with html}
make html
rm -rf build/html/.buildinfo
%endif
%if %{with pdf}
make latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_notebook

%if %{with pdf}
cp docs/build/latex/jupyter_core.pdf %{buildroot}%{_docdir}/python-jupyter_notebook/
%endif

%if %{with html}
cp -r docs/build/html %{buildroot}%{_docdir}/python-jupyter_notebook/
%endif

cp -r docs/source/examples %{buildroot}%{_docdir}/python-jupyter_notebook/

%fdupes %{buildroot}%{_docdir}/python-jupyter_notebook/

%if %{with tests}
%check
export LANG=en_US.UTF-8
%python_expand nosetests-%{$python_bin_suffix}
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.md
%{_docdir}/python-jupyter_notebook/

%changelog
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 5.4.1
  * A security release to fix CVE-2018-8768.
* Thu Feb 15 2018 toddrme2178@gmail.com
- update to version 5.4.0
  * Fix creating files and folders after navigating directories in the dashboard
    (:ghpull:`3264`).
  * Enable printing notebooks in colour, removing the CSS that made everything
    black and white (:ghpull:`3212`).
  * Limit the completion options displayed in the notebook to 1000, to avoid
    performance issues with very long lists (:ghpull:`3195`).
  * Accessibility improvements in ``tree.html`` (:ghpull:`3271`).
  * Added alt-text to the kernel logo image in the notebook UI (:ghpull:`3228`).
  * Added a test on Travis CI to flag if symlinks are accidentally introduced
    in the future. This should prevent the issue that necessitated
    :ref:`release-5.3.1` (:ghpull:`3227`).
  * Use lowercase letters for random IDs generated in our Javascript
    (:ghpull:`3264`).
  * Removed duplicate code setting ``TextCell.notebook`` (:ghpull:`3256`).
* Thu Jan 18 2018 toddrme2178@gmail.com
- update to version 5.3.1
  * Add support for terminals on windows (:ghpull:`3087`).
  * Add a "restart and run all" button to the toolbar (:ghpull:`2965`).
  * Send files to os trash mechanism on delete (:ghpull:`1968`).
  * Allow programmatic copy to clipboard (:ghpull:`3088`).
  * Use DOM History API for navigating between directories in the file browser (:ghpull:`3115`).
  * Add translated files to folder(docs-translations) (:ghpull:`3065`).
  * Allow non empty dirs to be deleted (:ghpull:`3108`).
  * Set cookie on base_url (:ghpull:`2959`).
  * Allow token-authenticated requests cross-origin by default (:ghpull:`2920`).
  * Change cull_idle_timeout_minimum to 1 from 300 (:ghpull:`2910`).
  * Config option to shut down server after n seconds with no kernels (:ghpull:`2963`).
  * Display a "close" button on load notebook error (:ghpull:`3176`).
  * Add action to command pallette to run CodeMirror's "indentAuto" on selection (:ghpull:`3175`).
  * Add option to specify extra services (:ghpull:`3158`).
  * Warn_bad_name should not use global name (:ghpull:`3160`).
  * Avoid overflow of hidden form (:ghpull:`3148`).
  * Fix shutdown trans loss (:ghpull:`3147`).
  * Find available kernelspecs more efficiently (:ghpull:`3136`).
  * Don\'t try to translate missing help strings (:ghpull:`3122`).
  * Frontend/extension-config: allow default json files in a .d directory (:ghpull:`3116`).
  * Use `requirejs` vs. `require` (:ghpull:`3097`).
  * Fixes some ui bugs in firefox #3044 (:ghpull:`3058`).
  * Compare non-specific language code when choosing to use arabic numerals (:ghpull:`3055`).
  * Fix save-script deprecation (:ghpull:`3053`).
  * Include moment locales in package_data (:ghpull:`3051`).
  * Fix moment locale loading in bidi support (:ghpull:`3048`).
  * Tornado 5: periodiccallback loop arg will be removed (:ghpull:`3034`).
  * Use `/files` prefix for pdf-like files (:ghpull:`3031`).
  * Add folder for document translation (:ghpull:`3022`).
  * When login-in via token, let a chance for user to set the password (:ghpull:`3008`).
  * Switch to jupyter_core implementation of ensure_dir_exists (:ghpull:`3002`).
  * Send http shutdown request on \'stop\' subcommand (:ghpull:`3000`).
  * Work on loading ui translations  (:ghpull:`2969`).
  * Fix ansi inverse (:ghpull:`2967`).
  * Add send2trash to requirements for building docs (:ghpull:`2964`).
  * I18n readme.md improvement (:ghpull:`2962`).
  * Add \'reason\' field to json error responses (:ghpull:`2958`).
  * Add some padding for stream outputs (:ghpull:`3194`).
  * Always use setuptools in ``setup.py`` (:ghpull:`3206`).
  * Fix clearing cookies on logout when ``base_url`` is configured (:ghpull:`3207`).
* Sun Dec  3 2017 arun@gmx.de
- update to version 5.2.2:
  * set cookie on base_urls (:ghpull:`2959`).
* Sat Nov  4 2017 arun@gmx.de
- update to version 5.2.1:
  * Fix invisible CodeMirror cursor at specific browser zoom levels
    (:ghpull:`2983`).
  * Fix nbconvert handler causing broken export to PDF
    (:ghpull:`2981`).
  * Fix the prompt_area argument of the output area
    constructor. (:ghpull:`2961`).
  * Handle a compound extension in new_untitled (:ghpull:`2949`).
  * Allow disabling offline message buffering (:ghpull:`2916`).
* Thu Oct 26 2017 toddrme2178@gmail.com
- Update to 5.2.0
  * Make all files in the dashboard editable by default and provide
    a whitelist of viewable file extensions (:ghpull:`2911`).
  * Ensure that the root directory is not hidden (:ghpull:`2907`).
  * Fix CodeMirror styling issue (:ghpull:`2880`).
  * Update error handling on ``APIHandlers`` (:ghpull:`2853`).
  * Upgrade xterm.js to 2.9.2 (:ghpull:`2849`).
  * Add Chinese translations (depends on upcoming UI implementation)
    (:ghpull:`2804`).
  * Allow for simpler customization of ``output_prompt`` in
    custom.js (:ghpull:`2774`).
  * Use RFC5987 encoding for filenames (:ghpull:`2767`).
  * Add path to the resources metadata (:ghpull:`2753`).
  * Make ``extraKeys`` consistent between notebook and editor views
    (:ghpull:`2745`).
  * Add RTL (right-to-left) support (:ghpull:`2357`).
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.1.0
  * Preliminary i18n implementation
  * Expose URL with auth token in notebook UI
  * Fix search background style
  * List running notebooks without requiring ``--allow-root``
  * Allow session of type other than notebook
  * Fix search background style
  * Fix some Markdown styling issues
  * Remove keymaps that conflict with non-English keyboards
  * Add session-specific favicons (notebook, terminal, file)
  * Add /api/shutdown handler
  * Include metadata when copying a cell
  * Stop notebook server from command line
  * Improve "View" and "Edit" file handling in dashboard
  * Provide a promise to replace use of the ``app_initialized.NotebookApp`` event
  * Fix disabled collapse/expand output button
  * Cull idle kernels using ``--MappingKernelManager.cull_idle_timeout``
  * Allow read-only notebooks to be trusted
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Remove unneeded python3 dependency.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to version 5.0.0
  * Files in the dashboard may now be sorted by last modified date or name (:ghpull:`943`):
  * There is a new cell toolbar for adding *cell tags* (:ghpull:`2048`):
  * The default styling for tables in the notebook has been updated (:ghpull:`1776`).
  * You can now edit keyboard shortcuts for *Command Mode* within the UI
  * You can copy and paste cells between notebooks, using :kbd:`Ctrl-C` and
    :kbd:`Ctrl-V` (:kbd:`Cmd-C` and :kbd:`Cmd-V` on Mac).
  * It's easier to configure a password for the notebook with the new
    ``jupyter notebook password`` command (:ghpull:`2007`).
  * The file list can now be ordered by *last modified* or by *name*
    (:ghpull:`943`).
  * Markdown cells now support attachments. Simply drag and drop an image from
    your desktop to a markdown cell to add it. Unlike relative links that you
    enter manually, attachments are embedded in the notebook itself. An
    unreferenced attachment will be automatically scrubbed from the notebook on
    save (:ghpull:`621`).
  * Undoing cell deletion now supports undeleting multiple cells. Cells may not be
    in the same order as before their deletion, depending on the actions you did
    on the meantime, but this should should help reduce the impact of
    accidentally deleting code.
  * The file browser now has *Edit* and *View* buttons.
  * The file browser now supports moving multiple files at once
    (:ghpull:`1088`).
  * The Notebook will refuse to run as root unless the ``--allow-root`` flag is
    given (:ghpull:`1115`).
  * Keyboard shortcuts are now declarative (:ghpull:`1234`).
  * Toggling line numbers can now affect all cells (:ghpull:`1312`).
  * Add more visible *Trusted* and *Untrusted* notifications (:ghpull:`1658`).
  * The favicon (browser shortcut icon) now changes to indicate when the kernel is busy
    (:ghpull:`1837`).
  * Header and toolbar visibility is now persisted in nbconfig and across sessions
    (:ghpull:`1769`).
  * Load server extensions with ConfigManager so that merge happens recursively,
    unlike normal config values, to make it load more consistently with frontend
    extensions(:ghpull:`2108`).
  * The notebook server now supports the `bundler API
    <http://jupyter-notebook.readthedocs.io/en/latest/extending/bundler_extensions.html>`__
    from the `jupyter_cms incubator project
    <https://github.com/jupyter-incubator/contentmanagement>`__ (:ghpull:`1579`).
  * The notebook server now provides information about kernel activity in
    its kernel resource API (:ghpull:`1827`).
- Update to 4.4.0
  * Allow override of output callbacks to redirect output messages. This is used to implement the ipywidgets Output widget, for example.
  * Fix an async bug in message handling by allowing comm message handlers to return a promise which halts message processing until the promise resolves.
- Update to 4.3.2
  * Monkey-patch for CodeMirror that resolves `#2037 <https://github.com/jupyter/notebook/issues/2037>`__ without breaking `#1967 <https://github.com/jupyter/notebook/issues/1967>`__
  * Read-only (``"editable": false``) cells can be executed but cannot be split, merged, or deleted
- Update to 4.3.1
  * CVE-2016-9971. Fix CSRF vulnerability,
    where malicious forms could create untitled files and start kernels
    (no remote execution or modification of existing files)
    for users of certain browsers (Firefox, Internet Explorer / Edge).
    All previous notebook releases are affected.
  - Bug fixes:
  * Fix carriage return handling
  * Make the font size more robust against fickle browsers
  * Ignore resize events that bubbled up and didn't come from window
  * Add Authorization to allowed CORS headers
  * Downgrade CodeMirror to 5.16 while we figure out issues in Safari
  - Other improvements:
  * Better docs for token-based authentication
  * Further highlight token info in log output when autogenerated
- Update to 4.3.0
  - Highlights:
  * API for creating mime-type based renderer extensions using :code:`OutputArea.register_mime_type` and :code:`Notebook.render_cell_output` methods. See `mimerender-cookiecutter <https://github.com/jupyterlab/mimerender-cookiecutter>`__ for reference implementations and cookiecutter.
  * Enable token authentication by default. See :ref:`server_security` for more details.
  * Update security docs to reflect new signature system
  * Switched from term.js to xterm.js
  - Bug fixes:
  * Ensure variable is set if exc_info is falsey
  * Catch and log handler exceptions in :code:`events.trigger`
  * Add debug log for static file paths
  * Don't check origin on token-authenticated requests
  * Remove leftover print statement
  * Fix highlighting of Python code blocks
  * :code:`json_errors` should be outermost decorator on API handlers
  * Fix remove old nbserver info files
  * Fix notebook mime type on download links
  * Fix carriage symbol bahvior
  * Fix terminal styles
  * Update dead links in docs
  * If kernel is broken, start a new session
  * Include cross-origin check when allowing login URL redirects
  - Other improvements:
  * Allow JSON output data with mime type "application/*+json"
  * Allow kernelspecs to have spaces in them for backward compat
  * Allow websocket connections from scripts
  * Allow :code:`None` for post_save_hook
  * Upgrade CodeMirror to 5.21
  * Upgrade xterm to 2.1.0
  * Docs for using comms
  * Set :code:`dirty` flag when output arrives
  * Set :code:`ws-url` data attribute when accessing a notebook terminal
  * Add base aliases for nbextensions
  * Include :code:`@` operator in CodeMirror IPython mode
  * Extend mathjax_url docstring
  * Load nbextension in predictable order
  * Improve the error messages for nbextensions
  * Include cross-origin check when allowing login URL redirects
- Update to 4.2.3
  * Fix regression in 4.2.2 that delayed loading custom.js
    until after ``notebook_loaded`` and ``app_initialized`` events have fired.
  * Fix some outdated docs and links.
- Update to 4.2.2
  * **Security fix**: CVE-2016-6524, where untrusted latex output
    could be added to the page in a way that could execute javascript.
  * Fix missing POST in OPTIONS responses.
  * Fix for downloading non-ascii filenames.
  * Avoid clobbering ssl_options, so that users can specify more detailed SSL configuration.
  * Fix inverted load order in nbconfig, so user config has highest priority.
  * Improved error messages here and there.
- Update to 4.2.1
  * Compatibility fixes for some versions of ipywidgets
  * Fix for ignored CSS on Windows
  * Fix specifying destination when installing nbextensions
- Update to 4.2.0
  * Upgrade MathJax to 2.6 to fix vertical-bar appearing on some equations.
  * Restore ability for notebook directory to be root (4.1 regression)
  * Large outputs are now throttled, reducing the ability of output floods to
    kill the browser.
  * Fix the notebook ignoring cell executions while a kernel is starting by queueing the messages.
  * Fix handling of url prefixes (e.g. JupyterHub) in terminal and edit pages.
  * Support nested SVGs in output.
- Create doc subpackage
* Mon Jan 11 2016 toddrme2178@gmail.com
- Update to 4.1.0
  + Bug fixes:
  - Properly reap zombie subprocesses
  - Fix cross-origin problems
  - Fix double-escaping of the base URL prefix
  - Handle invalid unicode filenames more gracefully
  - Fix ANSI color-processing
  - Send keepalive messages for web terminals
  - Fix bugs in the notebook tour
  + UI changes:
  - Moved the cell toolbar selector into the *View* menu. Added
    a button that triggers a "hint" animation to the main toolbar
    so users can find the new location.
  - Added *Restart & Run All* to the *Kernel* menu. Users can
    also bind it to a keyboard shortcut on action
    ``restart-kernel-and-run-all-cells``.
  - Added multiple-cell selection. Users press ``Shift-Up/Down``
    or ``Shift-K/J`` to extend selection in command mode.
    Various actions such as cut/copy/paste, execute, and cell
    type conversions apply to all selected cells.
  - Added a command palette for executing Jupyter actions by
    name. Users press ``Cmd/Ctrl-Shift-P`` or click the new
    command palette icon on the toolbar.
  - Added a *Find and Replace* dialog to the *Edit* menu.
    Users can also press ``F`` in command mode to show the
    dialog.
  + Other improvements:
  - Custom KernelManager methods can be Tornado coroutines,
    allowing async operations.
  - Make clearing output optional when rewriting input with
    ``set_next_input(replace=True)``.
  - Added support for TLS client authentication via
    ``--NotebookApp.client-ca``.
  - Added tags to ``jupyter/notebook`` releases on DockerHub.
    ``latest`` continues to track the master branch.
* Mon Oct 12 2015 toddrme2178@gmail.com
- update to version 4.0.6:
  * fix installation of mathjax support files
  * fix some double-escape regressions in 4.0.5
  * fix a couple of cases where errors could prevent opening a notebook
- specfile:
  * filename change: tgz->tar.gz
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 23 2015 toddrme2178@gmail.com
- Update to 4.0.5
  * Fix launching the notebook on Windows
  * Fix the path searched for frontend config
* Fri Aug 14 2015 toddrme2178@gmail.com
- Initial version
